==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/mk-MK/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Постои корисник со оваа е-пошта.',
    'account_not_found'      => 'Корисничкото име или лозинката се неточни.',
    'account_not_activated'  => 'Оваа корисничка сметка не е активирана.',
    'account_suspended'      => 'Оваа корисничка сметка е привремено блокирана.',
    'account_banned'         => 'Оваа корисничка сметка е блокирана.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Успешно сте најавени.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'Имаше проблем при обидот да се најавите, обидете се повторно.',
        'success' => 'Успешно сте најавени.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Имаше проблем при креирање на корисничката сметка, обидете се повторно.',
        'success' => 'Корисничката сметка е креирана.',
    ),

    'forgot-password' => array(
        'error'   => 'Имаше проблем при обидот да се добие кодот за ресетирање не лозинка, обидете се повторно.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Имаше проблем при ресетирање на лозинката, обидете се повторно.',
        'success' => 'Вашата лозинка е ресетирана.',
    ),


);

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/mk-MK/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Постои корисник со оваа е-пошта.',
    'account_not_found'      => 'Корисничкото име или лозинката се неточни.',
    'account_not_activated'  => 'Оваа корисничка сметка не е активирана.',
    'account_suspended'      => 'Оваа корисничка сметка е привремено блокирана.',
    'account_banned'         => 'Оваа корисничка сметка е блокирана.',
    'throttle'               => 'Премногу неуспешни обиди за најава. Обидете се повторно за :minutes минути.',

    'two_factor' => array(
        'already_enrolled'      => 'Вашиот уред е веќе запишан.',
        'success'               => 'Успешно сте најавени.',
        'code_required'         => 'Дво-факторски код е задолжителен.',
        'invalid_code'          => 'Дво-факторскиот код е невалиден.',
        'enter_two_factor_code' => 'Ве молиме внесете дво-факторски код за автентификација.',
        'please_enroll'         => 'Ве молиме запишете уред во двофакторна автентикација.',
    ),

    'signin' => array(
        'error'   => 'Имаше проблем при обидот да се најавите, обидете се повторно.',
        'success' => 'Успешно сте најавени.',
    ),

    'logout' => array(
        'error'   => 'Имаше проблем при обидот да ве одјавиме, обидете се повторно.',
        'success' => 'Успешно сте одјавени.',
    ),

    'signup' => array(
        'error'   => 'Имаше проблем при креирање на корисничката сметка, обидете се повторно.',
        'success' => 'Корисничката сметка е креирана.',
    ),

    'forgot-password' => array(
        'error'   => 'Имаше проблем при обидот да се добие кодот за ресетирање не лозинка, обидете се повторно.',
        'success' => 'Ако таа адреса на Е-пошта постои во нашиот систем, испратена ви е Е-пошта за обнова на лозинката.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Имаше проблем при ресетирање на лозинката, обидете се повторно.',
        'success' => 'Вашата лозинка е ресетирана.',
    ),


);
